@@ -1,6 +1,6 @@
 package Email::MIME::Kit;
 # ABSTRACT: build messages from templates
-$Email::MIME::Kit::VERSION = '3.000002';
+$Email::MIME::Kit::VERSION = '3.000003';
 require 5.008;
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -286,7 +286,7 @@ Email::MIME::Kit - build messages from templates
 
 =head1 VERSION
 
-version 3.000002
+version 3.000003
 
 =head1 SYNOPSIS
 
@@ -398,9 +398,29 @@ The development of this code was sponsored by Pobox.com.  Thanks, Pobox!
 
 Ricardo Signes <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Charlie Garrison fREW Schmidt hdp
+
+=over 4
+
+=item *
+
+Charlie Garrison <garrison@zeta.org.au>
+
+=item *
+
+fREW Schmidt <frioux@gmail.com>
+
+=item *
+
+hdp <hdp@1bcdbe44-fcfd-0310-b51b-975661d93aa0>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
