@@ -1,6 +1,6 @@
 package Email::MIME::Kit::ManifestReader::JSON;
 # ABSTRACT: read manifest.json files
-$Email::MIME::Kit::ManifestReader::JSON::VERSION = '3.000002';
+$Email::MIME::Kit::ManifestReader::JSON::VERSION = '3.000003';
 use Moose;
 
 with 'Email::MIME::Kit::Role::ManifestReader';
@@ -13,9 +13,7 @@ sub read_manifest {
 
   my $json_ref = $self->kit->kit_reader->get_kit_entry('manifest.json');
 
-  # We do not touch ->utf8 because we're reading the octets, and not decoding
-  # them. -- rjbs, 2014-11-20
-  my $content = JSON->new->decode($$json_ref);
+  my $content = JSON->new->utf8->decode($$json_ref);
 }
 
 no Moose;
@@ -34,7 +32,7 @@ Email::MIME::Kit::ManifestReader::JSON - read manifest.json files
 
 =head1 VERSION
 
-version 3.000002
+version 3.000003
 
 =head1 AUTHOR
 
@@ -42,7 +40,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
